# README.md in project root folder.





code block output block pair.

```python
def greeting(name: str) -> str:
    return 'Hello' + '\n\n' + name
print(greeting('World!'))
```

Here is the output it produces.
```
Hello

World!
```


```py
>>> print('Hello\n\nWorld!')
Hello
<BLANKLINE>
World!
```
